# coding: utf-8

u"""Модуль, содержащий валидаторы запрсов во ФСИН."""

from objectpack.exceptions import ValidationError


class BaseValidator(object):

    u"""Базовый валидатор."""

    # Параметры, общие для всех запросов
    base_params = {
        'SMEV_SENDER_CODE': u'Мнемоника системы в СМЭВ',
        'SMEV_SENDER_NAME': u'Название системы в СМЭВ',
        'FSIN_SMEV_CODE': u'Мнемоника системы ФСИН',
        'FSIN_SMEV_NAME': u'Название системы ФСИН',
        'SERVICE_CODE': u'SERVICE_CODE',
        'SENDER_CODE': u'SENDER_CODE',
        'MessageDate': u'Дата и время формирования запроса',
    }

    # Обязательные параметры
    required_params = NotImplemented

    def validate(self, params):
        u"""Выполняет валидацию переданных параметров.

        :param dict params: Словарь с параметрами запроса
        """
        self.required_params.update(self.base_params)
        for param, param_name in self.required_params.iteritems():
            if not params.get(param, False):
                raise ValidationError(
                    u'Не указан обязательный параметр: `{0}`'.format(
                        param_name
                    )
                )


class PutDocumentValidator(BaseValidator):

    u"""Валидатор параметров отправки заявления."""

    def __init__(self):
        u"""Задает обязательные параметры."""
        self.required_params = {
            'servantEmail': u'Email сотрудника',
            'senderOutDate': u'Дата формирования запроса',
            'CitizenAddress': u'Адрес гражданина',
            'citizenLastname': u'Фамилия гражданина',
            'citizenBirthdate': u'Дата рождения гражданина',
            'citizenFirstname': u'Имя гражданина',
            'citizenMiddlename': u'Отчество гражданина',
            'regionCode': u'Код субъекта РФ, в который направляется запрос',
        }


class GetDocumentResultValidator(BaseValidator):

    u"""Класс для проверки параметров запроса getResult."""

    def __init__(self):
        u"""Задает обязательные параметры."""
        self.required_params = {
            'RequestIdRef': u'Идентификатор сообщения',
            'OriginRequestIdRef': u'Идентификатор исходного сообщения',
            'CaseNumber': u'Номер запроса',
        }
